'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var GEO_API_URL = 'https://freegeoip.app/json/';
var COUNTRY_META_API = 'https://restcountries.eu/rest/v2/alpha/';
var EXCHANGE_RATES_API = 'https://openexchangerates.org/api/latest.json';
var QUANDL_API = 'https://www.quandl.com/api/v3/';

var getYear = function getYear() {
  return new Date().getFullYear();
};

var getLastYear = function getLastYear() {
  return getYear() - 1;
};

var getQuandlApiUrl = function getQuandlApiUrl(quandlApiKey, countryCodeIsoAlpha3) {
  return QUANDL_API + 'datasets/ODA/' + countryCodeIsoAlpha3 + '_PPPEX.json?start_date=' + getLastYear() + '-01-01&end_date=' + getYear() + '-01-01&api_key=' + quandlApiKey;
};

var mapGeoToPpp = function mapGeoToPpp(response) {
  return {
    countryName: response.data.country_name,
    countryCodeIsoAlpha2: response.data.country_code
  };
};

var getGeo = function getGeo() {
  return _axios2.default.get(GEO_API_URL).then(mapGeoToPpp);
};

var mapCountryMetaToPpp = function mapCountryMetaToPpp(pppInformation) {
  return function (response) {
    return _extends({}, pppInformation, {
      currenciesCountry: response.data.currencies,
      countryCodeIsoAlpha3: response.data.alpha3Code
    });
  };
};

var fetchCountryMeta = function fetchCountryMeta(pppInformation) {
  return _axios2.default.get('' + COUNTRY_META_API + pppInformation.countryCodeIsoAlpha2).then(mapCountryMetaToPpp(pppInformation));
};

var findExchangeRate = function findExchangeRate(exchangeRates, currenciesCountry) {
  for (var i = 0; i < currenciesCountry.length; i++) {
    if (exchangeRates[currenciesCountry[i].code]) {
      return _extends({
        exchangeRate: exchangeRates[currenciesCountry[i].code]
      }, currenciesCountry[i]);
    } else {
      return {
        exchangeRate: 1
      };
    }
  }
};

var mapExchangeRatesToPpp = function mapExchangeRatesToPpp(pppInformation) {
  return function (response) {
    return _extends({}, pppInformation, {
      currencyMain: findExchangeRate(response.data.rates, pppInformation.currenciesCountry)
    });
  };
};

var fetchExchangedRates = function fetchExchangedRates(openexchangeratesApiKey) {
  return function (country) {
    return _axios2.default.get(EXCHANGE_RATES_API + '?app_id=' + openexchangeratesApiKey).then(mapExchangeRatesToPpp(country));
  };
};

var mapToPpp = function mapToPpp(pppInformation) {
  return function (response) {
    return _extends({}, pppInformation, {
      ppp: response.data.dataset.data[0][1]
    });
  };
};

var fetchPpp = function fetchPpp(quandlApiKey) {
  return function (pppInformation) {
    return _axios2.default.get(getQuandlApiUrl(quandlApiKey, pppInformation.countryCodeIsoAlpha3)).then(mapToPpp(pppInformation));
  };
};

var computePppConversionFactor = function computePppConversionFactor(_ref) {
  var currencyMain = _ref.currencyMain,
      ppp = _ref.ppp;
  return ppp / currencyMain.exchangeRate;
};

var getPppConversionFactor = function getPppConversionFactor(pppInformation) {
  return _extends({}, pppInformation, {
    pppConversionFactor: computePppConversionFactor(pppInformation)
  });
};

var getPpp = function getPpp(openexchangeratesApiKey, quandlApiKey) {
  return getGeo().then(fetchCountryMeta).then(fetchExchangedRates(openexchangeratesApiKey)).then(fetchPpp(quandlApiKey)).then(getPppConversionFactor).catch(function () {
    try {
      throw new Error('Failed to fetch purchasing parity power.');
    } catch (e) {
      throw e;
    }
  });
};

exports.default = getPpp;